@@ -240,7 +240,7 @@ apply_button_clicked_cb (GtkButton         *button,
 	GtkWidget       *window;
 	GtkWidget       *viewer_page;
 
-	image = gth_image_rotator_get_result (GTH_IMAGE_ROTATOR (self->priv->rotator), TRUE);
+	image = gth_image_rotator_get_result (GTH_IMAGE_ROTATOR (self->priv->rotator), FALSE);
 
 	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
@@ -251,21 +251,6 @@ apply_button_clicked_cb (GtkButton         *button,
 }
 
 
-static void
-cancel_button_clicked_cb (GtkButton         *button,
-			  GthFileToolRotate *self)
-{
-	GtkWidget *window;
-	GtkWidget *viewer_page;
-
-	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
-	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
-	gth_image_viewer_page_reset (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-
-	gth_file_tool_hide_options (GTH_FILE_TOOL (self));
-}
-
-
 static void
 crop_settings_changed_cb (GtkAdjustment     *adj,
 		          GthFileToolRotate *self)
@@ -400,17 +385,20 @@ gth_file_tool_rotate_get_options (GthFileTool *base)
 
 	self->priv->builder = _gtk_builder_new_from_file ("rotate-options.ui", "file_tools");
 
-	self->priv->rotation_angle_adj = gimp_scale_entry_new (GET_WIDGET ("rotation_angle_hbox"),
-							       GTK_LABEL (GET_WIDGET ("rotation_angle_label")),
-							       0.0, -90.0, 90.0, 0.1, 1.0, 1);
+	self->priv->rotation_angle_adj = gth_color_scale_label_new (GET_WIDGET ("rotation_angle_hbox"),
+								    GTK_LABEL (GET_WIDGET ("rotation_angle_label")),
+								    GTH_COLOR_SCALE_DEFAULT,
+								    0.0, -180.0, 180.0, 0.1, 1.0, "%+.1f°");
 
-	self->priv->crop_p1_adj = gimp_scale_entry_new (GET_WIDGET ("crop_p1_hbox"),
-							GTK_LABEL (GET_WIDGET ("crop_p1_label")),
-							1.0, 0.0, 1.0, 0.001, 0.01, 3);
+	self->priv->crop_p1_adj = gth_color_scale_label_new (GET_WIDGET ("crop_p1_hbox"),
+							     GTK_LABEL (GET_WIDGET ("crop_p1_label")),
+							     GTH_COLOR_SCALE_DEFAULT,
+							     1.0, 0.0, 1.0, 0.001, 0.01, "%.3f");
 
-	self->priv->crop_p2_adj = gimp_scale_entry_new (GET_WIDGET ("crop_p2_hbox"),
-							GTK_LABEL (GET_WIDGET ("crop_p2_label")),
-							1.0, 0.0, 1.0, 0.001, 0.01, 3);
+	self->priv->crop_p2_adj = gth_color_scale_label_new (GET_WIDGET ("crop_p2_hbox"),
+							     GTK_LABEL (GET_WIDGET ("crop_p2_label")),
+							     GTH_COLOR_SCALE_DEFAULT,
+							     1.0, 0.0, 1.0, 0.001, 0.01, "%.3f");
 
 	self->priv->crop_grid = _gtk_combo_box_new_with_texts (_("None"),
 							       _("Rule of Thirds"),
@@ -468,10 +456,10 @@ gth_file_tool_rotate_get_options (GthFileTool *base)
 			  "clicked",
 			  G_CALLBACK (apply_button_clicked_cb),
 			  self);
-	g_signal_connect (GET_WIDGET ("cancel_button"),
-			  "clicked",
-			  G_CALLBACK (cancel_button_clicked_cb),
-			  self);
+	g_signal_connect_swapped (GET_WIDGET ("cancel_button"),
+				  "clicked",
+				  G_CALLBACK (gth_file_tool_cancel),
+				  self);
 	g_signal_connect (GET_WIDGET ("reset_button"),
 			  "clicked",
 			  G_CALLBACK (reset_button_clicked_cb),
@@ -571,7 +559,6 @@ gth_file_tool_rotate_destroy_options (GthFileTool *base)
 	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
 	viewer = gth_image_viewer_page_get_image_viewer (GTH_IMAGE_VIEWER_PAGE (viewer_page));
 	gth_image_viewer_set_tool (GTH_IMAGE_VIEWER (viewer), NULL);
-	gth_image_viewer_set_zoom_enabled (GTH_IMAGE_VIEWER (viewer), TRUE);
 	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (viewer_page));
 
 	cairo_surface_destroy (self->priv->image);
@@ -589,6 +576,19 @@ gth_file_tool_rotate_activate (GthFileTool *base)
 }
 
 
+static void
+gth_file_tool_rotate_cancel (GthFileTool *base)
+{
+	GthFileToolRotate *self = (GthFileToolRotate *) base;
+	GtkWidget         *window;
+	GtkWidget         *viewer_page;
+
+	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
+	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
+	gth_image_viewer_page_reset (GTH_IMAGE_VIEWER_PAGE (viewer_page));
+}
+
+
 static void
 gth_file_tool_rotate_finalize (GObject *object)
 {
@@ -622,6 +622,7 @@ gth_file_tool_rotate_class_init (GthFileToolRotateClass *klass)
 	file_tool_class = (GthFileToolClass *) klass;
 	file_tool_class->update_sensitivity = gth_file_tool_rotate_update_sensitivity;
 	file_tool_class->activate = gth_file_tool_rotate_activate;
+	file_tool_class->cancel = gth_file_tool_rotate_cancel;
 	file_tool_class->get_options = gth_file_tool_rotate_get_options;
 	file_tool_class->destroy_options = gth_file_tool_rotate_destroy_options;
 }
