@@ -41,6 +41,8 @@ typedef struct {
 	FlickrPrivacyType    privacy_level;
 	FlickrSafetyType     safety_level;
 	gboolean             hidden;
+	int                  max_width;
+	int                  max_height;
 	GList               *file_list;
 	GCancellable        *cancellable;
         GAsyncReadyCallback  callback;
@@ -765,6 +767,8 @@ post_photo_file_buffer_ready_cb (void     **buffer,
 	SoupMultipart *multipart;
 	char          *uri;
 	SoupBuffer    *body;
+	void          *resized_buffer;
+	gsize          resized_count;
 	SoupMessage   *msg;
 
 	if (error != NULL) {
@@ -823,8 +827,28 @@ post_photo_file_buffer_ready_cb (void     **buffer,
 
 	/* the file part */
 
+	if (_g_buffer_resize_image (*buffer,
+				    count,
+				    file_data,
+				    self->priv->post_photos->max_width,
+				    self->priv->post_photos->max_height,
+				    &resized_buffer,
+				    &resized_count,
+				    self->priv->post_photos->cancellable,
+				    &error))
+	{
+		body = soup_buffer_new (SOUP_MEMORY_TAKE, resized_buffer, resized_count);
+	}
+	else if (error == NULL) {
+		body = soup_buffer_new (SOUP_MEMORY_TEMPORARY, *buffer, count);
+	}
+	else {
+		soup_multipart_free (multipart);
+		post_photos_done (self, error);
+		return;
+	}
+
 	uri = g_file_get_uri (file_data->file);
-	body = soup_buffer_new (SOUP_MEMORY_TEMPORARY, *buffer, count);
 	soup_multipart_append_form_file (multipart,
 					 "photo",
 					 uri,
@@ -867,11 +891,11 @@ flickr_service_post_current_file (FlickrService *self)
 	}
 
 	file_data = self->priv->post_photos->current->data;
-	g_load_file_async (file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   self->priv->post_photos->cancellable,
-			   post_photo_file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    self->priv->post_photos->cancellable,
+			    post_photo_file_buffer_ready_cb,
+			    self);
 }
 
 
@@ -906,6 +930,8 @@ flickr_service_post_photos (FlickrService       *self,
 			    FlickrPrivacyType    privacy_level,
 			    FlickrSafetyType     safety_level,
 			    gboolean             hidden,
+			    int                  max_width,
+			    int                  max_height,
 			    GList               *file_list, /* GFile list */
 			    GCancellable        *cancellable,
 			    GAsyncReadyCallback  callback,
@@ -918,6 +944,8 @@ flickr_service_post_photos (FlickrService       *self,
 	self->priv->post_photos->privacy_level = privacy_level;
 	self->priv->post_photos->safety_level = safety_level;
 	self->priv->post_photos->hidden = hidden;
+	self->priv->post_photos->max_width = max_width;
+	self->priv->post_photos->max_height = max_height;
 	self->priv->post_photos->cancellable = _g_object_ref (cancellable);
 	self->priv->post_photos->callback = callback;
 	self->priv->post_photos->user_data = user_data;
@@ -1167,18 +1195,18 @@ GList *
 flickr_accounts_load_from_file (const char *server_name)
 {
 	GList       *accounts = NULL;
-	char        *filename;
+	GFile       *file;
 	char        *buffer;
 	char        *accounts_filename;
 	gsize        len;
 	DomDocument *doc;
 
 	accounts_filename = get_server_accounts_filename (server_name);
-	filename = gth_user_dir_get_file (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
+	file = gth_user_dir_get_file_for_read (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
 	g_free (accounts_filename);
 
-	if (! g_file_get_contents (filename, &buffer, &len, NULL)) {
-		g_free (filename);
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
+		g_object_unref (file);
 		return NULL;
 	}
 
@@ -1210,7 +1238,7 @@ flickr_accounts_load_from_file (const char *server_name)
 
 	g_object_unref (doc);
 	g_free (buffer);
-	g_free (filename);
+	g_object_unref (file);
 
 	return accounts;
 }
@@ -1243,7 +1271,6 @@ flickr_accounts_save_to_file (const char    *server_name,
 	char        *buffer;
 	gsize        len;
 	char        *accounts_filename;
-	char        *filename;
 	GFile       *file;
 
 	doc = dom_document_new ();
@@ -1262,15 +1289,12 @@ flickr_accounts_save_to_file (const char    *server_name,
 	}
 
 	accounts_filename = get_server_accounts_filename (server_name);
-	gth_user_dir_make_dir_for_file (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
-	filename = gth_user_dir_get_file (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
-	file = g_file_new_for_path (filename);
+	file = gth_user_dir_get_file_for_write (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
 	buffer = dom_document_dump (doc, &len);
-	g_write_file (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
+	_g_file_write (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
 
 	g_free (buffer);
 	g_object_unref (file);
-	g_free (filename);
 	g_free (accounts_filename);
 	g_object_unref (doc);
 }
