@@ -883,7 +883,8 @@ album_combobox_changed_cb (GtkComboBox *widget,
 
 
 GthImage *
-picasa_web_thumbnail_loader (GthFileData   *file_data,
+picasa_web_thumbnail_loader (GInputStream  *istream,
+			     GthFileData   *file_data,
 			     int            requested_size,
 			     int           *original_width,
 			     int           *original_height,
@@ -916,7 +917,7 @@ picasa_web_thumbnail_loader (GthFileData   *file_data,
 		gsize  size;
 
 		file = g_file_new_for_uri (uri);
-		if (g_load_file_in_buffer (file, &buffer, &size, cancellable, error)) {
+		if (_g_file_load_in_buffer (file, &buffer, &size, cancellable, error)) {
 			GInputStream *stream;
 			GdkPixbuf    *pixbuf;
 
