@@ -83,24 +83,6 @@ ok_button_clicked_cb (GtkButton         *button,
 }
 
 
-static void
-cancel_button_clicked_cb (GtkButton         *button,
-			  GthFileToolRedEye *self)
-{
-	GtkWidget *window;
-	GtkWidget *viewer_page;
-	GtkWidget *viewer;
-
-	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
-	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
-	viewer = gth_image_viewer_page_get_image_viewer (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-
-	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (viewer), self->priv->original_zoom_change);
-	gth_image_viewer_page_reset (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-	gth_file_tool_hide_options (GTH_FILE_TOOL (self));
-}
-
-
 static int
 find_region (int   row,
  	     int   col,
@@ -404,10 +386,10 @@ gth_file_tool_red_eye_get_options (GthFileTool *base)
 	self->priv->builder = _gtk_builder_new_from_file ("red-eye-removal-options.ui", "red_eye_removal");
 	options = _gtk_builder_get_widget (self->priv->builder, "options");
 	gtk_widget_show (options);
-	g_signal_connect (GET_WIDGET ("cancel_button"),
-			  "clicked",
-			  G_CALLBACK (cancel_button_clicked_cb),
-			  self);
+	g_signal_connect_swapped (GET_WIDGET ("cancel_button"),
+				  "clicked",
+				  G_CALLBACK (gth_file_tool_cancel),
+				  self);
 	g_signal_connect (GET_WIDGET ("ok_button"),
 			  "clicked",
 			  G_CALLBACK (ok_button_clicked_cb),
@@ -462,6 +444,23 @@ gth_file_tool_red_eye_activate (GthFileTool *base)
 }
 
 
+static void
+gth_file_tool_red_eye_cancel (GthFileTool *base)
+{
+	GthFileToolRedEye *self = (GthFileToolRedEye *) base;
+	GtkWidget         *window;
+	GtkWidget         *viewer_page;
+	GtkWidget         *viewer;
+
+	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
+	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
+	viewer = gth_image_viewer_page_get_image_viewer (GTH_IMAGE_VIEWER_PAGE (viewer_page));
+
+	gth_image_viewer_set_zoom_change (GTH_IMAGE_VIEWER (viewer), self->priv->original_zoom_change);
+	gth_image_viewer_page_reset (GTH_IMAGE_VIEWER_PAGE (viewer_page));
+}
+
+
 static void
 gth_file_tool_red_eye_finalize (GObject *object)
 {
@@ -496,6 +495,7 @@ gth_file_tool_red_eye_class_init (GthFileToolRedEyeClass *class)
 	file_tool_class = (GthFileToolClass *) class;
 	file_tool_class->update_sensitivity = gth_file_tool_red_eye_update_sensitivity;
 	file_tool_class->activate = gth_file_tool_red_eye_activate;
+	file_tool_class->cancel = gth_file_tool_red_eye_cancel;
 	file_tool_class->get_options = gth_file_tool_red_eye_get_options;
 	file_tool_class->destroy_options = gth_file_tool_red_eye_destroy_options;
 }
